# Recipes

This module contains classes that abstract common analysis procedure steps.

Recipes index:

- [Cookie box](cookiebox.md)
    - [CookieboxCalibration][extra.recipes.CookieboxCalibration]
- [Grating](grating.md)
    - [Grating2DCalibration][extra.recipes.Grating2DCalibration]
- [eTOF response analysis](cookiebox_deconvolve.md)
    - [TOFAnalogResponse][extra.recipes.TOFAnalogResponse]
    - [TOFResponse][extra.recipes.TOFResponse]
